@@ -31,7 +31,7 @@ CGetResponse
 CGetResponse
 ::CGetResponse(
     Value::Integer message_id_being_responded_to, Value::Integer status,
-    DataSet const & dataset)
+    std::shared_ptr<DataSet> dataset)
 : Response(message_id_being_responded_to, status)
 {
     this->set_command_field(Command::C_GET_RSP);
@@ -39,70 +39,43 @@ CGetResponse
 }
 
 CGetResponse
-::CGetResponse(
-    Value::Integer message_id_being_responded_to, Value::Integer status,
-    DataSet && dataset)
-: Response(message_id_being_responded_to, status)
-{
-    this->set_command_field(Command::C_GET_RSP);
-    this->set_data_set(std::move(dataset));
-}
-
-CGetResponse
-::CGetResponse(Message const & message)
+::CGetResponse(std::shared_ptr<Message> message)
 : Response(message)
 {
     this->_parse(message);
-    if(message.has_data_set())
+    if(message->has_data_set())
     {
-        this->set_data_set(message.get_data_set());
+        this->set_data_set(message->get_data_set());
     }
 }
 
-CGetResponse
-::CGetResponse(Message && message)
-: Response(message)
-{
-    this->_parse(message);
-    if(message.has_data_set())
-    {
-        this->set_data_set(std::move(message.get_data_set()));
-    }
-}
-
-CGetResponse
-::~CGetResponse()
-{
-    // Nothing to do.
-}
-
 void
 CGetResponse
-::_parse(Message const & message)
+::_parse(std::shared_ptr<Message const> message)
 {
-    if(message.get_command_field() != Command::C_GET_RSP)
+    if(!message || message->get_command_field() != Command::C_GET_RSP)
     {
         throw Exception("Message is not a C-GET-RSP");
     }
-    this->set_command_field(message.get_command_field());
+    this->set_command_field(message->get_command_field());
 
     ODIL_MESSAGE_SET_OPTIONAL_FIELD_MACRO(
-        message.get_command_set(), message_id, registry::MessageID, as_int)
+        message->get_command_set(), message_id, registry::MessageID, as_int)
     ODIL_MESSAGE_SET_OPTIONAL_FIELD_MACRO(
-        message.get_command_set(), affected_sop_class_uid,
+        message->get_command_set(), affected_sop_class_uid,
         registry::AffectedSOPClassUID, as_string)
 
     ODIL_MESSAGE_SET_OPTIONAL_FIELD_MACRO(
-        message.get_command_set(), number_of_remaining_sub_operations,
+        message->get_command_set(), number_of_remaining_sub_operations,
         registry::NumberOfRemainingSuboperations, as_int)
     ODIL_MESSAGE_SET_OPTIONAL_FIELD_MACRO(
-        message.get_command_set(), number_of_completed_sub_operations,
+        message->get_command_set(), number_of_completed_sub_operations,
         registry::NumberOfCompletedSuboperations, as_int)
     ODIL_MESSAGE_SET_OPTIONAL_FIELD_MACRO(
-        message.get_command_set(), number_of_failed_sub_operations,
+        message->get_command_set(), number_of_failed_sub_operations,
         registry::NumberOfFailedSuboperations, as_int)
     ODIL_MESSAGE_SET_OPTIONAL_FIELD_MACRO(
-        message.get_command_set(), number_of_warning_sub_operations,
+        message->get_command_set(), number_of_warning_sub_operations,
         registry::NumberOfWarningSuboperations, as_int)
 }
 
