@@ -86,10 +86,18 @@ void update_0022(
     public_dictionary.emplace(Tag(0x0022, 0x1029), ElementsDictionaryEntry("IOL Formula Detail", "IOLFormulaDetail",  "LO", "1"));
     public_dictionary.emplace(Tag(0x0022, 0x1033), ElementsDictionaryEntry("Keratometer Index", "KeratometerIndex",  "FL", "1"));
     public_dictionary.emplace(Tag(0x0022, 0x1035), ElementsDictionaryEntry("Source of Ophthalmic Axial Length Code Sequence", "SourceOfOphthalmicAxialLengthCodeSequence",  "SQ", "1"));
+    public_dictionary.emplace(Tag(0x0022, 0x1036), ElementsDictionaryEntry("Source of Corneal Size Data Code Sequence", "SourceOfCornealSizeDataCodeSequence",  "SQ", "1"));
     public_dictionary.emplace(Tag(0x0022, 0x1037), ElementsDictionaryEntry("Target Refraction", "TargetRefraction",  "FL", "1"));
     public_dictionary.emplace(Tag(0x0022, 0x1039), ElementsDictionaryEntry("Refractive Procedure Occurred", "RefractiveProcedureOccurred",  "CS", "1"));
     public_dictionary.emplace(Tag(0x0022, 0x1040), ElementsDictionaryEntry("Refractive Surgery Type Code Sequence", "RefractiveSurgeryTypeCodeSequence",  "SQ", "1"));
     public_dictionary.emplace(Tag(0x0022, 0x1044), ElementsDictionaryEntry("Ophthalmic Ultrasound Method Code Sequence", "OphthalmicUltrasoundMethodCodeSequence",  "SQ", "1"));
+    public_dictionary.emplace(Tag(0x0022, 0x1045), ElementsDictionaryEntry("Surgically Induced Astigmatism Sequence", "SurgicallyInducedAstigmatismSequence",  "SQ", "1"));
+    public_dictionary.emplace(Tag(0x0022, 0x1046), ElementsDictionaryEntry("Type of Optical Correction", "TypeOfOpticalCorrection",  "CS", "1"));
+    public_dictionary.emplace(Tag(0x0022, 0x1047), ElementsDictionaryEntry("Toric IOL Power Sequence", "ToricIOLPowerSequence",  "SQ", "1"));
+    public_dictionary.emplace(Tag(0x0022, 0x1048), ElementsDictionaryEntry("Predicted Toric Error Sequence", "PredictedToricErrorSequence",  "SQ", "1"));
+    public_dictionary.emplace(Tag(0x0022, 0x1049), ElementsDictionaryEntry("Pre-Selected for Implantation", "PreSelectedForImplantation",  "CS", "1"));
+    public_dictionary.emplace(Tag(0x0022, 0x104a), ElementsDictionaryEntry("Toric IOL Power for Exact Emmetropia Sequence", "ToricIOLPowerForExactEmmetropiaSequence",  "SQ", "1"));
+    public_dictionary.emplace(Tag(0x0022, 0x104b), ElementsDictionaryEntry("Toric IOL Power for Exact Target Refraction Sequence", "ToricIOLPowerForExactTargetRefractionSequence",  "SQ", "1"));
     public_dictionary.emplace(Tag(0x0022, 0x1050), ElementsDictionaryEntry("Ophthalmic Axial Length Measurements Sequence", "OphthalmicAxialLengthMeasurementsSequence",  "SQ", "1"));
     public_dictionary.emplace(Tag(0x0022, 0x1053), ElementsDictionaryEntry("IOL Power", "IOLPower",  "FL", "1"));
     public_dictionary.emplace(Tag(0x0022, 0x1054), ElementsDictionaryEntry("Predicted Refractive Error", "PredictedRefractiveError",  "FL", "1"));
@@ -111,6 +119,9 @@ void update_0022(
     public_dictionary.emplace(Tag(0x0022, 0x1125), ElementsDictionaryEntry("Anterior Chamber Depth Definition Code Sequence", "AnteriorChamberDepthDefinitionCodeSequence",  "SQ", "1"));
     public_dictionary.emplace(Tag(0x0022, 0x1127), ElementsDictionaryEntry("Lens Thickness Sequence", "LensThicknessSequence",  "SQ", "1"));
     public_dictionary.emplace(Tag(0x0022, 0x1128), ElementsDictionaryEntry("Anterior Chamber Depth Sequence", "AnteriorChamberDepthSequence",  "SQ", "1"));
+    public_dictionary.emplace(Tag(0x0022, 0x112a), ElementsDictionaryEntry("Calculation Comment Sequence", "CalculationCommentSequence",  "SQ", "1"));
+    public_dictionary.emplace(Tag(0x0022, 0x112b), ElementsDictionaryEntry("Calculation Comment Type", "CalculationCommentType",  "CS", "1"));
+    public_dictionary.emplace(Tag(0x0022, 0x112c), ElementsDictionaryEntry("Calculation Comment", "CalculationComment",  "LT", "1"));
     public_dictionary.emplace(Tag(0x0022, 0x1130), ElementsDictionaryEntry("Lens Thickness", "LensThickness",  "FL", "1"));
     public_dictionary.emplace(Tag(0x0022, 0x1131), ElementsDictionaryEntry("Anterior Chamber Depth", "AnteriorChamberDepth",  "FL", "1"));
     public_dictionary.emplace(Tag(0x0022, 0x1132), ElementsDictionaryEntry("Source of Lens Thickness Data Code Sequence", "SourceOfLensThicknessDataCodeSequence",  "SQ", "1"));
@@ -250,10 +261,18 @@ void update_0022(
     public_tags.emplace("IOLFormulaDetail", Tag(0x0022, 0x1029));
     public_tags.emplace("KeratometerIndex", Tag(0x0022, 0x1033));
     public_tags.emplace("SourceOfOphthalmicAxialLengthCodeSequence", Tag(0x0022, 0x1035));
+    public_tags.emplace("SourceOfCornealSizeDataCodeSequence", Tag(0x0022, 0x1036));
     public_tags.emplace("TargetRefraction", Tag(0x0022, 0x1037));
     public_tags.emplace("RefractiveProcedureOccurred", Tag(0x0022, 0x1039));
     public_tags.emplace("RefractiveSurgeryTypeCodeSequence", Tag(0x0022, 0x1040));
     public_tags.emplace("OphthalmicUltrasoundMethodCodeSequence", Tag(0x0022, 0x1044));
+    public_tags.emplace("SurgicallyInducedAstigmatismSequence", Tag(0x0022, 0x1045));
+    public_tags.emplace("TypeOfOpticalCorrection", Tag(0x0022, 0x1046));
+    public_tags.emplace("ToricIOLPowerSequence", Tag(0x0022, 0x1047));
+    public_tags.emplace("PredictedToricErrorSequence", Tag(0x0022, 0x1048));
+    public_tags.emplace("PreSelectedForImplantation", Tag(0x0022, 0x1049));
+    public_tags.emplace("ToricIOLPowerForExactEmmetropiaSequence", Tag(0x0022, 0x104a));
+    public_tags.emplace("ToricIOLPowerForExactTargetRefractionSequence", Tag(0x0022, 0x104b));
     public_tags.emplace("OphthalmicAxialLengthMeasurementsSequence", Tag(0x0022, 0x1050));
     public_tags.emplace("IOLPower", Tag(0x0022, 0x1053));
     public_tags.emplace("PredictedRefractiveError", Tag(0x0022, 0x1054));
@@ -275,6 +294,9 @@ void update_0022(
     public_tags.emplace("AnteriorChamberDepthDefinitionCodeSequence", Tag(0x0022, 0x1125));
     public_tags.emplace("LensThicknessSequence", Tag(0x0022, 0x1127));
     public_tags.emplace("AnteriorChamberDepthSequence", Tag(0x0022, 0x1128));
+    public_tags.emplace("CalculationCommentSequence", Tag(0x0022, 0x112a));
+    public_tags.emplace("CalculationCommentType", Tag(0x0022, 0x112b));
+    public_tags.emplace("CalculationComment", Tag(0x0022, 0x112c));
     public_tags.emplace("LensThickness", Tag(0x0022, 0x1130));
     public_tags.emplace("AnteriorChamberDepth", Tag(0x0022, 0x1131));
     public_tags.emplace("SourceOfLensThicknessDataCodeSequence", Tag(0x0022, 0x1132));
