@@ -320,6 +320,14 @@ void update_0040(
     public_dictionary.emplace(Tag(0x0040, 0xa731), ElementsDictionaryEntry("Relationship Sequence (Trial)", "RelationshipSequenceTrial",  "SQ", "1"));
     public_dictionary.emplace(Tag(0x0040, 0xa732), ElementsDictionaryEntry("Relationship Type Code Sequence (Trial)", "RelationshipTypeCodeSequenceTrial",  "SQ", "1"));
     public_dictionary.emplace(Tag(0x0040, 0xa744), ElementsDictionaryEntry("Language Code Sequence (Trial)", "LanguageCodeSequenceTrial",  "SQ", "1"));
+    public_dictionary.emplace(Tag(0x0040, 0xa801), ElementsDictionaryEntry("Tabulated Values Sequence", "TabulatedValuesSequence",  "SQ", "1"));
+    public_dictionary.emplace(Tag(0x0040, 0xa802), ElementsDictionaryEntry("Number of Table Rows", "NumberOfTableRows",  "UL", "1"));
+    public_dictionary.emplace(Tag(0x0040, 0xa803), ElementsDictionaryEntry("Number of Table Columns", "NumbeOfTableColumns",  "UL", "1"));
+    public_dictionary.emplace(Tag(0x0040, 0xa804), ElementsDictionaryEntry("Table Row Number", "TableRowNumber",  "UL", "1"));
+    public_dictionary.emplace(Tag(0x0040, 0xa805), ElementsDictionaryEntry("Table Column Number", "TableColumnNumber",  "UL", "1"));
+    public_dictionary.emplace(Tag(0x0040, 0xa806), ElementsDictionaryEntry("Table Row Definition Sequence", "TableRowDefinitionSequence",  "SQ", "1"));
+    public_dictionary.emplace(Tag(0x0040, 0xa807), ElementsDictionaryEntry("Table Column Definition Sequence", "TableColumnDefinitionSequence",  "SQ", "1"));
+    public_dictionary.emplace(Tag(0x0040, 0xa808), ElementsDictionaryEntry("Cell Values Sequence", "CellValuesSequence",  "SQ", "1"));
     public_dictionary.emplace(Tag(0x0040, 0xa992), ElementsDictionaryEntry("Uniform Resource Locator (Trial)", "UniformResourceLocatorTrial",  "ST", "1"));
     public_dictionary.emplace(Tag(0x0040, 0xb020), ElementsDictionaryEntry("Waveform Annotation Sequence", "WaveformAnnotationSequence",  "SQ", "1"));
     public_dictionary.emplace(Tag(0x0040, 0xdb00), ElementsDictionaryEntry("Template Identifier", "TemplateIdentifier",  "CS", "1"));
@@ -640,6 +648,14 @@ void update_0040(
     public_tags.emplace("RelationshipSequenceTrial", Tag(0x0040, 0xa731));
     public_tags.emplace("RelationshipTypeCodeSequenceTrial", Tag(0x0040, 0xa732));
     public_tags.emplace("LanguageCodeSequenceTrial", Tag(0x0040, 0xa744));
+    public_tags.emplace("TabulatedValuesSequence", Tag(0x0040, 0xa801));
+    public_tags.emplace("NumberOfTableRows", Tag(0x0040, 0xa802));
+    public_tags.emplace("NumbeOfTableColumns", Tag(0x0040, 0xa803));
+    public_tags.emplace("TableRowNumber", Tag(0x0040, 0xa804));
+    public_tags.emplace("TableColumnNumber", Tag(0x0040, 0xa805));
+    public_tags.emplace("TableRowDefinitionSequence", Tag(0x0040, 0xa806));
+    public_tags.emplace("TableColumnDefinitionSequence", Tag(0x0040, 0xa807));
+    public_tags.emplace("CellValuesSequence", Tag(0x0040, 0xa808));
     public_tags.emplace("UniformResourceLocatorTrial", Tag(0x0040, 0xa992));
     public_tags.emplace("WaveformAnnotationSequence", Tag(0x0040, 0xb020));
     public_tags.emplace("TemplateIdentifier", Tag(0x0040, 0xdb00));
