@@ -316,6 +316,14 @@ Tag const ContentSequence(0x0040, 0xa730);
 Tag const RelationshipSequenceTrial(0x0040, 0xa731);
 Tag const RelationshipTypeCodeSequenceTrial(0x0040, 0xa732);
 Tag const LanguageCodeSequenceTrial(0x0040, 0xa744);
+Tag const TabulatedValuesSequence(0x0040, 0xa801);
+Tag const NumberOfTableRows(0x0040, 0xa802);
+Tag const NumbeOfTableColumns(0x0040, 0xa803);
+Tag const TableRowNumber(0x0040, 0xa804);
+Tag const TableColumnNumber(0x0040, 0xa805);
+Tag const TableRowDefinitionSequence(0x0040, 0xa806);
+Tag const TableColumnDefinitionSequence(0x0040, 0xa807);
+Tag const CellValuesSequence(0x0040, 0xa808);
 Tag const UniformResourceLocatorTrial(0x0040, 0xa992);
 Tag const WaveformAnnotationSequence(0x0040, 0xb020);
 Tag const TemplateIdentifier(0x0040, 0xdb00);
