@@ -376,6 +376,7 @@ Tag const ScanSpotPositionMap(0x300a, 0x0394);
 Tag const ScanSpotReorderingAllowed(0x300a, 0x0395);
 Tag const ScanSpotMetersetWeights(0x300a, 0x0396);
 Tag const ScanningSpotSize(0x300a, 0x0398);
+Tag const ScanSpotSizesDelivered(0x300a, 0x0399);
 Tag const NumberOfPaintings(0x300a, 0x039a);
 Tag const IonToleranceTableSequence(0x300a, 0x03a0);
 Tag const IonBeamSequence(0x300a, 0x03a2);
@@ -559,6 +560,47 @@ Tag const NumberOfPatientSupportDevices(0x300a, 0x0687);
 Tag const RTBeamModifierDefinitionDistance(0x300a, 0x0688);
 Tag const BeamAreaLimitSequence(0x300a, 0x0689);
 Tag const ReferencedRTPrescriptionSequence(0x300a, 0x068a);
+Tag const TreatmentSessionUID(0x300a, 0x0700);
+Tag const RTRadiationUsage(0x300a, 0x0701);
+Tag const ReferencedRTRadiationSetSequence(0x300a, 0x0702);
+Tag const ReferencedRTRadiationRecordSequence(0x300a, 0x0703);
+Tag const RTRadiationSetDeliveryNumber(0x300a, 0x0704);
+Tag const ClinicalFractionNumber(0x300a, 0x0705);
+Tag const RTTreatmentFractionCompletionStatus(0x300a, 0x0706);
+Tag const RTRadiationSetUsage(0x300a, 0x0707);
+Tag const TreatmentDeliveryContinuationFlag(0x300a, 0x0708);
+Tag const TreatmentRecordContentOrigin(0x300a, 0x0709);
+Tag const RTTreatmentTerminationStatus(0x300a, 0x0714);
+Tag const RTTreatmentTerminationReasonCodeSequence(0x300a, 0x0715);
+Tag const MachineSpecificTreatmentTerminationCodeSequence(0x300a, 0x0716);
+Tag const RTRadiationSalvageRecordControlPointSequence(0x300a, 0x0722);
+Tag const StartingMetersetValueKnownFlag(0x300a, 0x0723);
+Tag const TreatmentTerminationDescription(0x300a, 0x0730);
+Tag const TreatmentToleranceViolationSequence(0x300a, 0x0731);
+Tag const TreatmentToleranceViolationCategory(0x300a, 0x0732);
+Tag const TreatmentToleranceViolationAttributeSequence(0x300a, 0x0733);
+Tag const TreatmentToleranceViolationDescription(0x300a, 0x0734);
+Tag const TreatmentToleranceViolationIdentification(0x300a, 0x0735);
+Tag const TreatmentToleranceViolationDateTime(0x300a, 0x0736);
+Tag const RecordedRTControlPointDateTime(0x300a, 0x073a);
+Tag const ReferencedRadiationRTControlPointIndex(0x300a, 0x073b);
+Tag const AlternateValueSequence(0x300a, 0x073e);
+Tag const ConfirmationSequence(0x300a, 0x073f);
+Tag const InterlockSequence(0x300a, 0x0740);
+Tag const InterlockDateTime(0x300a, 0x0741);
+Tag const InterlockDescription(0x300a, 0x0742);
+Tag const InterlockOriginatingDeviceSequence(0x300a, 0x0743);
+Tag const InterlockCodeSequence(0x300a, 0x0744);
+Tag const InterlockResolutionCodeSequence(0x300a, 0x0745);
+Tag const InterlockResolutionUserSequence(0x300a, 0x0746);
+Tag const OverrideDateTime(0x300a, 0x0760);
+Tag const TreatmentToleranceViolationTypeCodeSequence(0x300a, 0x0761);
+Tag const TreatmentToleranceViolationCauseCodeSequence(0x300a, 0x0762);
+Tag const MeasuredMetersetToDoseMappingSequence(0x300a, 0x0772);
+Tag const ReferencedExpectedInVivoMeasurementValueIndex(0x300a, 0x0773);
+Tag const DoseMeasurementDeviceCodeSequence(0x300a, 0x0774);
+Tag const AdditionalParameterRecordingInstanceSequence(0x300a, 0x0780);
+Tag const InterlockOriginDescription(0x300a, 0x0783);
 
 }
 
