@@ -11,6 +11,9 @@
 
 #include "odil/EchoSCP.h"
 
+#include "opaque_types.h"
+#include "type_casters.h"
+
 namespace
 {
 
